=========================
Sample Configuration File
=========================

The following is a sample ironic-neutron-agent configuration for adaptation and
use. For a detailed overview of all available configuration options, refer to
:doc:`config`.

The sample configuration can also be viewed in :download:`file form
</_static/ironic_neutron_agent.ini.conf.sample>`.

.. important::

   The sample configuration file is auto-generated from networking-baremetal
   when this documentation is built. You must ensure your version of
   networking-baremetal matches the version of this documentation.

.. literalinclude:: /_static/ironic_neutron_agent.ini.conf.sample